function K = drvAssembleMtx(K,e,ke)
% Assemble global stiffness matrix.
% Input/output arguments:
%  K:    global stiffness matrix
% Input arguments:
%  e:    element number
%  ke:   element local stiffness matrix

 include_gblrefs;

 % Assemble element gather vector (stores element d.o.f. eqn. numbers)
 i = 0;
 for j = 1:nen
  for k = 1:ndof
   i = i + 1;
   gle(i) = ID(k,IEN(j,e));
  end
 end

 % Add contribution of element given by its id to global stiffness matrix
 % il is the local (element) row equation number
 % jl is the local (element) column equation number
 % ig is the global row equation number
 % jg is the global column equation number

 %%% COMPLETE HERE 25 %%%

end
